..  This file is part of Invenio
    Copyright (C) 2014, 2015 CERN.

    Invenio is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio-Kwalitee; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

    In applying this licence, CERN does not waive the privileges and immunities
    granted to it by virtue of its status as an Intergovernmental Organization
    or submit itself to any jurisdiction.

.. _ext_session:


Session
=======

.. automodule:: invenio_ext.session
   :members:
   :undoc-members:
   :show-inheritance:


Backends
--------

.. automodule:: invenio_ext.session.backends
   :members:
   :undoc-members:
   :show-inheritance:

Cache
^^^^^

.. automodule:: invenio_ext.session.backends.cache
   :members:
   :undoc-members:
   :show-inheritance:

SQLAlchemy
^^^^^^^^^^

.. automodule:: invenio_ext.session.backends.sqlalchemy
   :members:
   :undoc-members:
   :show-inheritance:


Model
`````

.. automodule:: invenio_ext.session.model
   :members:
   :undoc-members:


Wrappers
--------

.. automodule:: invenio_ext.session.interface
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: invenio_ext.session.storage
   :members:
   :undoc-members:
   :show-inheritance:
